@@ -24,13 +24,11 @@ from scrapy.utils.project import get_project_settings
 from scrapy.utils.reqser import request_to_dict, request_from_dict
 
 from .redis_dupefilter import RFPDupeFilter
-from kazoo.handlers.threading import KazooTimeoutError
 from .redis_domain_max_page_filter import RFDomainMaxPageFilter
 from .redis_global_page_per_domain_filter import RFGlobalPagePerDomainFilter
 
 from bhfutils.scutils.log_factory import LogFactory
 from bhfutils.scutils.redis_queue import RedisPriorityQueue
-from bhfutils.scutils.zookeeper_watcher import ZookeeperWatcher
 from bhfutils.scutils.redis_throttled_queue import RedisThrottledQueue
 
 settings = get_project_settings()
@@ -70,7 +68,6 @@ class DistributedScheduler(object):
     my_id = None  # The id used to read the throttle config
     config_flag = False  # Flag to reload queues if settings are wiped too
     assign_path = None  # The base assigned configuration path to read
-    zoo_client = None  # The KazooClient to manage the config
     my_assignment = None  # Zookeeper path to read actual yml config
     black_domains = []  # the domains to ignore thanks to zookeeper config
 
@@ -111,27 +108,6 @@ class DistributedScheduler(object):
         # if we need better uuid's mod this line
         self.my_uuid = str(uuid.uuid4()).split('-')[4]
 
-    def setup_zookeeper(self):
-        self.assign_path = settings.get('ZOOKEEPER_ASSIGN_PATH', "")
-        self.my_id = settings.get('ZOOKEEPER_ID', 'all')
-        self.logger.debug("Trying to establish Zookeeper connection")
-        try:
-            self.zoo_watcher = ZookeeperWatcher(
-                hosts=settings.get('ZOOKEEPER_HOSTS'),
-                filepath=self.assign_path + self.my_id,
-                config_handler=self.change_config,
-                error_handler=self.error_config,
-                pointer=False, ensure=True, valid_init=True)
-        except KazooTimeoutError:
-            self.logger.error("Could not connect to Zookeeper")
-            sys.exit(1)
-
-        if self.zoo_watcher.ping():
-            self.logger.debug("Successfully set up Zookeeper connection")
-        else:
-            self.logger.error("Could not ping Zookeeper")
-            # sys.exit(1)
-
     def change_config(self, config_string):
         if config_string and len(config_string) > 0:
             loaded_config = yaml.safe_load(config_string)
@@ -388,7 +364,6 @@ class DistributedScheduler(object):
         self.spider = spider
         self.spider.set_logger(self.logger)
         self.create_queues()
-        self.setup_zookeeper()
         self.dupefilter = RFPDupeFilter(self.redis_conn,
                                         self.spider.name + ':dupefilter',
                                         self.rfp_timeout)
