@@ -2,12 +2,10 @@ import asyncio
 import logging
 
 from time import time
-
 from .. import bhf_signals
 from contextlib import suppress
 from inspect import isawaitable
 from ipaddress import ip_address
-from bhfutils.crawler.playwright.stealth import stealth_async
 from typing import Callable, Dict, Generator, Optional, Tuple, Type, TypeVar
 
 from playwright.async_api import (
@@ -18,6 +16,7 @@ from playwright.async_api import (
     Response as PlaywrightResponse,
     Route,
 )
+from playwright_stealth import stealth_async
 from scrapy import Spider, signals
 from scrapy.crawler import Crawler
 from scrapy.http import Request, Response
@@ -74,6 +73,7 @@ def _get_page_method_result(page: Page, pm: PageMethod):
 class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
     def __init__(self, crawler: Crawler) -> None:
         super().__init__(settings=crawler.settings, crawler=crawler)
+        asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
         verify_installed_reactor("twisted.internet.asyncioreactor.AsyncioSelectorReactor")
         crawler.signals.connect(self._engine_started, signals.engine_started)
         self.stats = crawler.stats
@@ -119,10 +119,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     def _engine_started(self) -> Deferred:
         """Launch the browser. Use the engine_started signal as it supports returning deferreds."""
-        if not self.playwright_user_agents:
-            return deferred_from_coro(self._launch_browser())
-        else:
-            return deferred_from_coro(self._launch_browser(user_agent=self.playwright_user_agents[1]))
+        return deferred_from_coro(self._launch_browser())
 
     def _ip_changed(self) -> Deferred:
         """Plan User-Agent rotation"""
